@@ -1,4 +1,4 @@
-from numpy import zeros, array, average, append
+from numpy import zeros, array, average, append, delete, insert, arange
 import matplotlib.pyplot as plt
 import matplotlib.image as image
 import matplotlib.colors as colors
@@ -214,3 +214,25 @@ def plot2D_deform(up,defo,cnx,ax,color='RdYlGn_r',bar_label='Resultados',logo=Tr
     plt.axis('off'); plt.axis('equal')
     plt.tight_layout()
 
+
+def V_insert(V, BC_data, ElementData):
+    '''Función que agrega valores nulos aun vector en pocisiones especificadas
+    '''
+    for BC in BC_data:
+      if int(BC[1])==1:
+        i = int(BC[0])*ElementData.dof + int(BC[2])-1
+        V = insert(V, i, 0)
+    return V
+
+def K_reduce(K, BC_data, ElementData):
+    '''Función que elimina grados de libertad que no se desea analizar
+    '''
+    (n,m) = K.shape
+    dof = arange(0,n,1,'int')
+    li = []
+    for BC in BC_data:
+      if int(BC[1])==1:
+        li.append(int(BC[0])*ElementData.dof + int(BC[2])-1)
+    dof = delete(dof,li)
+    Kr = K[dof][:,dof]
+    return Kr
\ No newline at end of file
