@@ -473,15 +473,10 @@ def Bernoulli(A, x, N, dN, ddN, ProblemData, ElementData, ModelData, dX, tipo):
         ##
     elif tipo == 'MasaConcentrada':
         rho = ModelData.density
-        B = rho*N.T@N*dX*Area
-        ##
-        one = zeros(m*n)
-        one[:] = 1.0
-        B = B@one
         A = zeros((m*n, m*n))
-        # Concentrando Masas (Mejorar proceso si |A| <= 0)
         for i in range(m*n):
-            A[i, i] = B[i]
+            if i%2==1: A[i, i] = 0.5*rho*dX*Area
+            else: A[i, i] = 0.005*rho*dX*Area
         ##
     elif(tipo == 'VectorF'):
         # Formando matriz N para v
